`timescale 1 ns / 1 ps

module test_sc;
  reg tbreset, tbstrtstop;
  reg tbclk;
  wire [6:0] onesout, tensout;
  wire [9:0] tbtenthsout;

parameter cycles = 25;

reg [9:0] Data_in_t [0:cycles];


// /////////////////////////////
// Instantiatation of the Design
// /////////////////////////////

stopwatch UUT (.CLK (tbclk), .RESET (tbreset), .STRTSTOP (tbstrtstop),
  .ONESOUT (onesout), .TENSOUT (tensout), .TENTHSOUT (tbtenthsout));

   wire [4:0] tbonesout, tbtensout;

   assign tbtensout = led2hex(tensout);
   assign tbonesout = led2hex(onesout);

initial begin

        Data_in_t[1] =10'b1111111110; 
        Data_in_t[2] =10'b1111111101; 
        Data_in_t[3] =10'b1111111011; 
        Data_in_t[4] =10'b1111110111;
       	Data_in_t[5] =10'b1111101111; 
        Data_in_t[6] =10'b1111011111;
        Data_in_t[7] =10'b1110111111; 
        Data_in_t[8] =10'b1101111111; 
        Data_in_t[9] =10'b1011111111; 
        Data_in_t[10]=10'b0111111111;
        Data_in_t[11]=10'b1111111110; 
        Data_in_t[12]=10'b1111111110; 
        Data_in_t[13]=10'b1111111101; 
        Data_in_t[14]=10'b1111111011;
       	Data_in_t[15]=10'b1111110111; 
        Data_in_t[16]=10'b1111101111;
        Data_in_t[17]=10'b1111011111; 
        Data_in_t[18]=10'b1110111111; 
        Data_in_t[19]=10'b1101111111; 
        Data_in_t[20]=10'b1011111111; 
        Data_in_t[21]=10'b0111111111; 
        Data_in_t[22]=10'b1111111110; 
        Data_in_t[23]=10'b1111111110; 
        Data_in_t[24]=10'b1111111101;
       	Data_in_t[25]=10'b1111111011;
end

reg GSR;
assign glbl.GSR = GSR;

initial begin

    GSR = 1;

    // ///////////////////////////////
    // Wait till Global Reset Finished
    // ///////////////////////////////
    #100 GSR = 0;
end
 
// ////////////////
// Create the clock
// ////////////////

initial begin
    tbclk = 0;
    // Wait till Global Reset Finished, then cycle clock
    #100 forever #60 tbclk = ~tbclk;
end

initial begin

    // //////////////////////////
    // Initialize All Input Ports
    // //////////////////////////

    tbreset = 1;
    tbstrtstop = 1;

    // /////////////////////
    // Apply Design Stimulus
    // /////////////////////

    #240 tbreset = 0;
     tbstrtstop = 0;
    #5000 tbstrtstop = 1;
    #8125 tbstrtstop = 0;
    #500 tbstrtstop = 1;
    #875 tbreset = 1;
    #375 tbreset = 0;
    #700 tbstrtstop = 0;
    #550 tbstrtstop = 1;

    // /////////////////////////////////////////////////////
    // simulation must be halted inside an initial statement
    // /////////////////////////////////////////////////////

//    #100000 $stop;
end

function [4:0] led2hex;
input [6:0] LED ;

//HEX-to-seven-segment decoder
//
// segment encoding
//      0
//     ---  
//  5 |   | 1
//     ---   <- 6
//  4 |   | 2
//     ---
//      3

case (LED)
        7'b1111001 : led2hex = 4'd1;
	7'b0100100 : led2hex = 4'd2;
	7'b0110000 : led2hex = 4'd3;
	7'b0011001 : led2hex = 4'd4;
	7'b0010010 : led2hex = 4'd5;
	7'b0000010 : led2hex = 4'd6;
	7'b1111000 : led2hex = 4'd7;
	7'b0000000 : led2hex = 4'd8;
	7'b0010000 : led2hex = 4'd9;
	default : led2hex = 4'd0;
endcase
endfunction

integer i,errors;

always @ (posedge tbclk)
begin
  if (tbstrtstop)
    begin
    i = 0;
    errors = 0;
    end
  else 
  begin
        for (i = 1; i <= cycles; i = i + 1)
        begin
          @(negedge tbclk) 
          // check result at negedge
          $display("Time%d ns; TBSTRTSTOP=%b; Reset=%h; Expected TenthsOut=%b; Actual TenthsOut=%b", $stime, tbstrtstop, tbreset, Data_in_t[i], tbtenthsout);
          if ( tbtenthsout !== Data_in_t[i] )
            begin
            $display(" ------ERROR. A mismatch has occurred-----");
            errors = errors + 1;
            end
        end
   if (errors == 0)
     $display("Simulation finished Successfully.");
   else if (errors > 1)
     $display("%0d ERROR! See log above for details.",errors);
   else
     $display("ERROR! See log above for details."); 
#100 $stop; 
  end
end

endmodule 


